summaryrefslogtreecommitdiff
path: root/arch/nios2
diff options
context:
space:
mode:
authorEric W. Biederman <ebiederm@xmission.com>2021-06-28 14:52:01 -0500
committerEric W. Biederman <ebiederm@xmission.com>2021-12-13 12:04:45 -0600
commit0e25498f8cd43c1b5aa327f373dd094e9a006da7 (patch)
treef9f4cf6d7c1deccaa34ad6f7af345bff52b63c12 /arch/nios2
parent5e354747b2c91f64544b97760d38e2d3280307b2 (diff)
exit: Add and use make_task_dead.
There are two big uses of do_exit. The first is it's design use to be the guts of the exit(2) system call. The second use is to terminate a task after something catastrophic has happened like a NULL pointer in kernel code. Add a function make_task_dead that is initialy exactly the same as do_exit to cover the cases where do_exit is called to handle catastrophic failure. In time this can probably be reduced to just a light wrapper around do_task_dead. For now keep it exactly the same so that there will be no behavioral differences introducing this new concept. Replace all of the uses of do_exit that use it for catastraphic task cleanup with make_task_dead to make it clear what the code is doing. As part of this rename rewind_stack_do_exit rewind_stack_and_make_dead. Signed-off-by: "Eric W. Biederman" <ebiederm@xmission.com>
Diffstat (limited to 'arch/nios2')
-rw-r--r--arch/nios2/kernel/traps.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/nios2/kernel/traps.c b/arch/nios2/kernel/traps.c
index 596986a74a26..85ac49d64cf7 100644
--- a/arch/nios2/kernel/traps.c
+++ b/arch/nios2/kernel/traps.c
@@ -37,10 +37,10 @@ void die(const char *str, struct pt_regs *regs, long err)
show_regs(regs);
spin_unlock_irq(&die_lock);
/*
* do_exit() should take care of panic'ing from an interrupt
* context so we don't handle it here
*/
- do_exit(err);
+ make_task_dead(err);
}
void _exception(int signo, struct pt_regs *regs, int code, unsigned long addr)
@@ -37,10 +37,10 @@ void die(const char *str, struct pt_regs *regs, long err)
spin_unlock_irq(&die_lock);
/*
- * do_exit() should take care of panic'ing from an interrupt
+ * make_task_dead() should take care of panic'ing from an interrupt
* context so we don't handle it here
*/